==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/Web/Gui/Resources/translations/Web_ro.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ro" sourcelanguage="en">
  <context>
    <name>CmdWebBrowserBack</name>
    <message>
      <location filename="../../Command.cpp" line="76"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="77"/>
      <source>Previous page</source>
      <translation>Pagina anterioară</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="78"/>
      <source>Go back to the previous page</source>
      <translation>Revino la pagina anterioară</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserNext</name>
    <message>
      <location filename="../../Command.cpp" line="105"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="106"/>
      <source>Next page</source>
      <translation>Pagina următoare</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="107"/>
      <source>Go to the next page</source>
      <translation>Avansează la pagina următoare</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserRefresh</name>
    <message>
      <location filename="../../Command.cpp" line="134"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="135"/>
      <location filename="../../Command.cpp" line="136"/>
      <source>Refresh web page</source>
      <translation>Reâmprospătează pagina web</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserStop</name>
    <message>
      <location filename="../../Command.cpp" line="162"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="163"/>
      <source>Stop loading</source>
      <translation>Oprește încărcarea</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="164"/>
      <source>Stop the current loading</source>
      <translation>Oprește încărcarea actuală</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomIn</name>
    <message>
      <location filename="../../Command.cpp" line="192"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="193"/>
      <source>Zoom in</source>
      <translation>Mărește</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="194"/>
      <source>Zoom into the page</source>
      <translation>Mărește în pagină</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomOut</name>
    <message>
      <location filename="../../Command.cpp" line="221"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="222"/>
      <source>Zoom out</source>
      <translation>Micșorează</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="223"/>
      <source>Zoom out of the page</source>
      <translation>Micșorează pagina</translation>
    </message>
  </context>
  <context>
    <name>CmdWebOpenWebsite</name>
    <message>
      <location filename="../../Command.cpp" line="50"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="51"/>
      <source>Open website...</source>
      <translation>Deschide pagina web...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="52"/>
      <source>Opens a website in FreeCAD</source>
      <translation>Deschide o pagină web în FreeCAD</translation>
    </message>
  </context>
  <context>
    <name>Form</name>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="14"/>
      <source>Sketchfab exporter</source>
      <translation type="unfinished">Sketchfab exporter</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="39"/>
      <source>What to upload?</source>
      <translation type="unfinished">What to upload?</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="46"/>
      <source>Selection</source>
      <translation>Selecţie</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="56"/>
      <source>All visible objects</source>
      <translation type="unfinished">All visible objects</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="81"/>
      <source>Model name</source>
      <translation type="unfinished">Model name</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="88"/>
      <source>Private</source>
      <translation type="unfinished">Private</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="100"/>
      <source>Description</source>
      <translation>Descriere</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="110"/>
      <source>Tags (separated by commas)</source>
      <translation type="unfinished">Tags (separated by commas)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="119"/>
      <source>FreeCAD,</source>
      <translation type="unfinished">FreeCAD,</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="135"/>
      <source>Format</source>
      <translation type="unfinished">Format</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="143"/>
      <source>OBJ + MTL (Arch exporter)</source>
      <translation type="unfinished">OBJ + MTL (Arch exporter)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="148"/>
      <source>OBJ (standard Mesh exporter)</source>
      <translation type="unfinished">OBJ (standard Mesh exporter)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="153"/>
      <source>DAE (Collada)</source>
      <translation type="unfinished">DAE (Collada)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="158"/>
      <source>STL</source>
      <translation type="unfinished">STL</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="163"/>
      <source>IGES (shapes only)</source>
      <translation type="unfinished">IGES (shapes only)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="168"/>
      <source>IV</source>
      <translation type="unfinished">IV</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="176"/>
      <source>Sketchfab API token</source>
      <translation type="unfinished">Sketchfab API token</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="192"/>
      <source>Obtain</source>
      <translation type="unfinished">Obtain</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="201"/>
      <source>Upload</source>
      <translation type="unfinished">Upload</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="211"/>
      <source>uploading</source>
      <translation type="unfinished">uploading</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="218"/>
      <source>Success! View uploaded online</source>
      <translation type="unfinished">Success! View uploaded online</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../AppWebGui.cpp" line="80"/>
      <location filename="../../BrowserView.cpp" line="412"/>
      <source>Browser</source>
      <translation>Navigator</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="309"/>
      <source>File does not exist!</source>
      <translation>Fișierul nu există!</translation>
    </message>
  </context>
  <context>
    <name>WebGui::BrowserView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="304"/>
      <source>Error</source>
      <translation>Eroare</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="383"/>
      <source>Loading %1...</source>
      <translation>Se încarcă %1...</translation>
    </message>
  </context>
  <context>
    <name>WebGui::WebView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="181"/>
      <source>Open in External Browser</source>
      <translation>Deschide în navigator extern</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="185"/>
      <source>Open in new window</source>
      <translation>Deschide intr-o fereastra noua</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="46"/>
      <source>Navigation</source>
      <translation>Navigare</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/Web/Gui/Resources/translations/Web_ro.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ro" sourcelanguage="en">
  <context>
    <name>CmdWebBrowserBack</name>
    <message>
      <location filename="../../Command.cpp" line="76"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="77"/>
      <source>Previous page</source>
      <translation>Pagina anterioară</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="78"/>
      <source>Go back to the previous page</source>
      <translation>Revino la pagina anterioară</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserNext</name>
    <message>
      <location filename="../../Command.cpp" line="105"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="106"/>
      <source>Next page</source>
      <translation>Pagina următoare</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="107"/>
      <source>Go to the next page</source>
      <translation>Avansează la pagina următoare</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserRefresh</name>
    <message>
      <location filename="../../Command.cpp" line="134"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="135"/>
      <location filename="../../Command.cpp" line="136"/>
      <source>Refresh web page</source>
      <translation>Reâmprospătează pagina web</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserStop</name>
    <message>
      <location filename="../../Command.cpp" line="162"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="163"/>
      <source>Stop loading</source>
      <translation>Oprește încărcarea</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="164"/>
      <source>Stop the current loading</source>
      <translation>Oprește încărcarea actuală</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomIn</name>
    <message>
      <location filename="../../Command.cpp" line="192"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="193"/>
      <source>Zoom in</source>
      <translation>Mărește</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="194"/>
      <source>Zoom into the page</source>
      <translation>Mărește în pagină</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomOut</name>
    <message>
      <location filename="../../Command.cpp" line="221"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="222"/>
      <source>Zoom out</source>
      <translation>Micșorează</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="223"/>
      <source>Zoom out of the page</source>
      <translation>Micșorează pagina</translation>
    </message>
  </context>
  <context>
    <name>CmdWebOpenWebsite</name>
    <message>
      <location filename="../../Command.cpp" line="50"/>
      <source>Web</source>
      <translation>Web</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="51"/>
      <source>Open website...</source>
      <translation>Deschide pagina web...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="52"/>
      <source>Opens a website in FreeCAD</source>
      <translation>Deschide o pagină web în FreeCAD</translation>
    </message>
  </context>
  <context>
    <name>Form</name>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="14"/>
      <source>Sketchfab exporter</source>
      <translation>Exportator de Sketchfab</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="39"/>
      <source>What to upload?</source>
      <translation>Ce să încărcaţi?</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="46"/>
      <source>Selection</source>
      <translation>Selecţie</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="56"/>
      <source>All visible objects</source>
      <translation>Toate obiectele vizibile</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="81"/>
      <source>Model name</source>
      <translation>Numele Modelului</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="88"/>
      <source>Private</source>
      <translation>Privat</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="100"/>
      <source>Description</source>
      <translation>Descriere</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="110"/>
      <source>Tags (separated by commas)</source>
      <translation>Tag-uri (separate prin virgulă)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="119"/>
      <source>FreeCAD,</source>
      <translation>FreeCAD,</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="135"/>
      <source>Format</source>
      <translation>Formatul</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="143"/>
      <source>OBJ + MTL (Arch exporter)</source>
      <translation>OBJ + MTL (exportator Arch)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="148"/>
      <source>OBJ (standard Mesh exporter)</source>
      <translation>OBJ (exportator de plasă standard)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="153"/>
      <source>DAE (Collada)</source>
      <translation>DAE (Collada)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="158"/>
      <source>STL</source>
      <translation>STL</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="163"/>
      <source>IGES (shapes only)</source>
      <translation>IGES (numai forme)</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="168"/>
      <source>IV</source>
      <translation>IV</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="176"/>
      <source>Sketchfab API token</source>
      <translation>Sketchfab API token</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="192"/>
      <source>Obtain</source>
      <translation>Obţine</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="201"/>
      <source>Upload</source>
      <translation>Încărcaţi</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="211"/>
      <source>uploading</source>
      <translation>încărcarea</translation>
    </message>
    <message>
      <location filename="../ui/TaskDlgSketchfab.ui" line="218"/>
      <source>Success! View uploaded online</source>
      <translation>Succes! Vezi încărcat online</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../AppWebGui.cpp" line="80"/>
      <location filename="../../BrowserView.cpp" line="440"/>
      <source>Browser</source>
      <translation>Navigator</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="337"/>
      <source>File does not exist!</source>
      <translation>Fișierul nu există!</translation>
    </message>
  </context>
  <context>
    <name>WebGui::BrowserView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="329"/>
      <location filename="../../BrowserView.cpp" line="333"/>
      <source>Error</source>
      <translation>Eroare</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="333"/>
      <source>There were errors while loading the file. Some data might have been modified or not recovered at all. Look in the report view for more specific information about the objects involved.</source>
      <translation>Au existat erori în timpul încărcării fişierului. Unele date s-ar putea să fi fost modificate sau să se nu recupereze deloc. Uitați-vă în raportul vizualizării pentru mai multe informaţii specifice despre obiectele implicate.</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="411"/>
      <source>Loading %1...</source>
      <translation>Se încarcă %1...</translation>
    </message>
  </context>
  <context>
    <name>WebGui::WebView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="185"/>
      <source>Open in External Browser</source>
      <translation>Deschide în navigator extern</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="189"/>
      <source>Open in new window</source>
      <translation>Deschide intr-o fereastra noua</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="46"/>
      <source>Navigation</source>
      <translation>Navigare</translation>
    </message>
  </context>
</TS>
